==> FK-2_8_9.tar.bz2: FK-2_8_9/FK/System.h <==
/****************************************************************************
 *
 *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
 *
 *	Redistribution and use in source and binary forms,
 *	with or without modification, are permitted provided that the
 *	following conditions are met:
 *
 *		- Redistributions of source code must retain the above
 *			copyright notice, this list of conditions and the
 *			following disclaimer.
 *
 *		- Redistributions in binary form must reproduce the above
 *			copyright notice, this list of conditions and the
 *			following disclaimer in the documentation and/or
 *			other materials provided with the distribution.
 *
 *		- Neither the name of the copyright holders nor the names
 *			of its contributors may be used to endorse or promote
 *			products derived from this software without specific
 *			prior written permission.
 *
 *	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *	"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *	LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *	FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *	COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 *	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *	SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *	HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 *	STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 *	IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *	POSSIBILITY OF SUCH DAMAGE. 
 *
 ****************************************************************************/
/****************************************************************************
 *
 *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
 *
 *	本ソフトウェアおよびソースコードのライセンスは、基本的に
 *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
 *
 *	ソースコード形式かバイナリ形式か、変更するかしないかを問わず、
 *	以下の条件を満たす場合に限り、再頒布および使用が許可されます。
 *
 *	- ソースコードを再頒布する場合、上記の著作権表示、本条件一覧、
 *		および下記免責条項を含めること。
 *
 *	- バイナリ形式で再頒布する場合、頒布物に付属のドキュメント等の
 *		資料に、上記の著作権表示、本条件一覧、および下記免責条項を
 *		含めること。
 *
 *	- 書面による特別の許可なしに、本ソフトウェアから派生した製品の
 *		宣伝または販売促進に、本ソフトウェアの著作権者の名前または
 *		コントリビューターの名前を使用してはならない。
 *
 *	本ソフトウェアは、著作権者およびコントリビューターによって「現
 *	状のまま」提供されており、明示黙示を問わず、商業的な使用可能性、
 *	および特定の目的に対する適合性に関す暗黙の保証も含め、またそれ
 *	に限定されない、いかなる保証もないものとします。著作権者もコン
 *	トリビューターも、事由のいかんを問わず、損害発生の原因いかんを
 *	問わず、かつ責任の根拠が契約であるか厳格責任であるか(過失その
 *	他の)不法行為であるかを問わず、仮にそのような損害が発生する可
 *	能性を知らされていたとしても、本ソフトウェアの使用によって発生
 *	した(代替品または代用サービスの調達、使用の喪失、データの喪失、
 *	利益の喪失、業務の中断も含め、またそれに限定されない)直接損害、
 *	間接損害、偶発的な損害、特別損害、懲罰的損害、または結果損害に
 *	ついて、一切責任を負わないものとします。
 *
 ****************************************************************************/
#ifndef __FK_SYSTEM_HEADER__
#define __FK_SYSTEM_HEADER__

#include <FK/Base.h>

//! システム依存関数集合クラス
/*!
 *	このクラスは、システムに依存する関数を
 *	static 関数群としてまとめたものです。
 *	全ての関数は static 宣言されているため、
 *	本クラスの関数を用いる際に
 *	fk_System 型のインスタンスを生成する必要はありません。
 *	例えば、以下のようにしてコードを記述します。
 *	\code
 *	fk_System::setcwd();
 *	\endcode
 */

class fk_System {
 public:

#if defined(_MACOSX_) || defined(_FREEBSD_) || defined(FK_DOXYGEN_USER_PROCESS)

	//! カレントディレクトリ設定関数
	/*!
	 *	実行プロセスのカレントディレクトリを、
	 *	プロセスを実行したシェルのディレクトリに設定します。
	 *	open コマンドを用いて実行した際に、
	 *	カレントディレクトリの設定が異なってしまう場合に便利です。
	 *
	 *	\return
	 *		設定に成功すれば true を、失敗すれば false を返します。
	 *
	 *	\note
	 *		この関数は、MacOSX や FreeBSD などの
	 *		UNIX 系システムでのみサポートされています。
	 *		Windows 系では関数自体が定義されていないため、
	 *		マルチプラットホームとなるプログラムとする場合、
	 *		以下の様に記述しておく必要があります。
	 *
	 *	\code
	 *	#if defined(_MACOSX_) || defined(_FREEBSD_)
	 *		fk_System::setcwd();
	 *	#endif
	 *	\endcode
	 */

	static bool setcwd(void);
#endif

};
	
#endif // !__FK_SYSTEM_HEADER__

==> FK-2_8_10.tar.bz2: FK-2_8_10/FK/System.h <==
/****************************************************************************
 *
 *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
 *
 *	Redistribution and use in source and binary forms,
 *	with or without modification, are permitted provided that the
 *	following conditions are met:
 *
 *		- Redistributions of source code must retain the above
 *			copyright notice, this list of conditions and the
 *			following disclaimer.
 *
 *		- Redistributions in binary form must reproduce the above
 *			copyright notice, this list of conditions and the
 *			following disclaimer in the documentation and/or
 *			other materials provided with the distribution.
 *
 *		- Neither the name of the copyright holders nor the names
 *			of its contributors may be used to endorse or promote
 *			products derived from this software without specific
 *			prior written permission.
 *
 *	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *	"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *	LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *	FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *	COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 *	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *	SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *	HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 *	STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 *	IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *	POSSIBILITY OF SUCH DAMAGE. 
 *
 ****************************************************************************/
/****************************************************************************
 *
 *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
 *
 *	本ソフトウェアおよびソースコードのライセンスは、基本的に
 *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
 *
 *	ソースコード形式かバイナリ形式か、変更するかしないかを問わず、
 *	以下の条件を満たす場合に限り、再頒布および使用が許可されます。
 *
 *	- ソースコードを再頒布する場合、上記の著作権表示、本条件一覧、
 *		および下記免責条項を含めること。
 *
 *	- バイナリ形式で再頒布する場合、頒布物に付属のドキュメント等の
 *		資料に、上記の著作権表示、本条件一覧、および下記免責条項を
 *		含めること。
 *
 *	- 書面による特別の許可なしに、本ソフトウェアから派生した製品の
 *		宣伝または販売促進に、本ソフトウェアの著作権者の名前または
 *		コントリビューターの名前を使用してはならない。
 *
 *	本ソフトウェアは、著作権者およびコントリビューターによって「現
 *	状のまま」提供されており、明示黙示を問わず、商業的な使用可能性、
 *	および特定の目的に対する適合性に関す暗黙の保証も含め、またそれ
 *	に限定されない、いかなる保証もないものとします。著作権者もコン
 *	トリビューターも、事由のいかんを問わず、損害発生の原因いかんを
 *	問わず、かつ責任の根拠が契約であるか厳格責任であるか(過失その
 *	他の)不法行為であるかを問わず、仮にそのような損害が発生する可
 *	能性を知らされていたとしても、本ソフトウェアの使用によって発生
 *	した(代替品または代用サービスの調達、使用の喪失、データの喪失、
 *	利益の喪失、業務の中断も含め、またそれに限定されない)直接損害、
 *	間接損害、偶発的な損害、特別損害、懲罰的損害、または結果損害に
 *	ついて、一切責任を負わないものとします。
 *
 ****************************************************************************/
#ifndef __FK_SYSTEM_HEADER__
#define __FK_SYSTEM_HEADER__

#include <FK/Base.h>

//! システム依存関数集合クラス
/*!
 *	このクラスは、システムに依存する関数を
 *	static 関数群としてまとめたものです。
 *	全ての関数は static 宣言されているため、
 *	本クラスの関数を用いる際に
 *	fk_System 型のインスタンスを生成する必要はありません。
 *	例えば、以下のようにしてコードを記述します。
 *	\code
 *	fk_System::setcwd();
 *	\endcode
 */

class fk_System {
 public:

	//! カレントディレクトリ設定関数
	/*!
	 *	実行プロセスのカレントディレクトリを、
	 *	プロセスを実行したシェルのディレクトリに設定します。
	 *	Mac での open コマンド実行時など、
	 *	カレントディレクトリの設定が異なってしまう場合に便利です。
	 *
	 *	Windows 環境で Visual Studio を利用している場合も、
	 *	Visual Studio 上から実行する時のカレントディレクトリと
	 *	exe ファイルが作成されるディレクトリが異なるため、
	 *	不都合が生じる場合があります。
	 *	この関数を用いて、実行時は常時 exe ファイルのあるパスが
	 *	カレントディレクトリになるよう統一すると便利でしょう。
	 *
	 *	\return
	 *		設定に成功すれば true を、失敗すれば false を返します。
	 *
	 *	\note
	 *		現時点でこの関数がサポートされている環境は
	 *		MacOS や FreeBSD 等のUNIX 系システムと Windows 環境です。
	 *		その他のプラットホームでは関数を呼んでも何も起こりません。
	 *
	 */

	static bool setcwd(void);

	//! カレントディレクトリ参照関数
	/*!
	 *	実行プロセスのカレントディレクトリを返します。
	 *
	 *	\return
	 *		参照に成功した場合、カレントディレクトリの絶対パスを
	 *		文字列として返します。失敗した場合は空文字列を返します。
	 *
	 *	\note
	 *		この関数は、MacOSX や FreeBSD などの
	 *		UNIX 系システムと Windows 環境でサポートされています。
	 *		その他のプラットホームでは、常に空文字を返します。
	 *
	 */

	static std::string get_cwd(void);

};
	
#endif // !__FK_SYSTEM_HEADER__
